from setuptools import setup

setup(
    name= "fc_bigdate9",
    version= "1.0",
    py_modules= ["fc_xd_bigdate"],
    author= "大数据3",
    author_email= "3145057077@qq.com",
    description= "大数据3"
)